@@ -2,7 +2,7 @@ package Audio::Extract::PCM::Backend::SoX;
 use strict;
 use warnings;
 use Carp;
-use IO::CaptureOutput qw( qxx );
+use IO::CaptureOutput qw( qxx qxy );
 use base qw(Audio::Extract::PCM::Backend);
 use Audio::Extract::PCM::Format;
 
@@ -108,35 +108,63 @@ sub pcm_back {
     # warn $soxerr if length $soxerr;
 
     # Now get the format data from stderr:
-    my %infos = (
-        # Parse table
-        map {
-            /^(.+?)\s*:\s*(.*?)\s*$/ ? (lc $1, $2) : ()
-        }
-        # Find output file stanza
-        grep {
-            /^Output File\s*:/i .. /^\s*$/
-        }
-        # Split lines
-        $soxerr =~ /[^\n\r]+/g
-    );
 
-    if ($ENV{DEBUG}) {
-        warn "SoX stderr:\n$soxerr\n";
+    my ($sample_size, $duration, $channels, $endian, $endfreq);
+
+    # Older soxes had a very different format of the -V3 output.  From sox's
+    # Changelog, I *assume* that it changed in 13.0.0.
+    # What I actually tested is 12.17.9 and 14.0.1, for sample output see the
+    # comment at the bottom of this module.
+
+
+    if (get_sox_version() >= '13.0.0') {
+
+        my %infos = (
+            # Parse table
+            map {
+                /^(.+?)\s*:\s*(.*?)\s*$/ ? (lc $1, $2) : ()
+            }
+            # Find output file stanza
+            grep {
+                /^Output File\s*:/i .. /^\s*$/
+            }
+            # Split lines
+            $soxerr =~ /[^\n\r]+/g
+        );
+
+        if ($ENV{DEBUG}) {
+            warn "SoX stderr:\n$soxerr\n";
+        }
+
+        $sample_size = $infos{'sample size'} or die "no sample size from sox";
+        $sample_size =~ s/^([0-9]+).*// or die "bad sample size from sox: $sample_size";
+        $sample_size = $1 / 8;
+
+        $duration = $infos{duration} or die "no duration from sox";
+        $duration =~ /^(\d+):(\d+\.\d+) / or die "bad duration from sox: $duration";
+        $duration = $1 * 60 + $2 ;
+
+        $channels = $infos{channels} or die "no channels from sox";
+        $endian = $infos{'endian type'} or die "no endianness from sox";
+        $endfreq = $infos{'sample rate'} or die "no sample rate from sox";
+
+    } else {
+        # sox < 13.0.0
+
+        my ($info) = $soxerr =~ m{^(sox: Writing Wave file:.*?bits/samp)}msi;
+
+        ($sample_size) = $info =~ m{(\d+) bits/samp}i or die "no sample size from sox";
+        $sample_size /= 8;
+
+        ($endfreq) = $info =~ m{(\d+) samp/sec}i or die "no sample rate from sox";
+        $endian = 'little'; # ?
+        ($channels) = $info =~ m{(\d+) channels}i or die "no channels from sox";
+
+        ($duration) = $soxerr =~ m{^sox: Finished writing.*?(\d+) samples}mi
+            or die "no duration from sox";
+        $duration /= $endfreq;
     }
 
-    my $sample_size = $infos{'sample size'} or die "no sample size from sox\n";
-    $sample_size =~ s/^([0-9]+).*// or die "bad sample size from sox: $sample_size\n";
-    $sample_size = $1 / 8;
-
-    my $duration = $infos{duration} or die "no duration from sox\n";
-    $duration =~ /^(\d+):(\d+\.\d+) / or die "bad duration from sox: $duration\n";
-    $duration = $1 * 60 + $2 ;
-
-    my $channels = $infos{channels} or die "no channels from sox\n";
-    my $endian = $infos{'endian type'} or die "no endianness from sox\n";
-    my $endfreq = $infos{'sample rate'} or die "no sample rate from sox\n";
-
     $endformat->combine(
         samplesize => $sample_size,
         duration => $duration,
@@ -166,8 +194,8 @@ This will return the SoX version as a L<version> object.  The result will be
 cached, i.e. if you install a new sox, this module will not recognize it until
 it is reloaded or the application using it is restarted.
 
-If no sox program is in the path or C<sox --version> outputs strange things,
-C<undef> will be returned.  In the latter case, a warning will be issued.
+If no sox program is in the path or C<sox -h> outputs strange things, C<undef>
+will be returned.  In the latter case, a warning will be issued.
 
 Currently, the only internal use is to find out whether SoX is above version
 13.0.0, because they renamed the C<"-b"/"-w"/"-l"/"-d"> flags to
@@ -187,13 +215,20 @@ C<"-1"/"-2"/"-4"/"-8"> by then.  Note that the old flags were still recognized
         # Older soxes print stuff like "sox: Version 12.17.9" in the first line of sox -h,
         # newer soxes print stuff like "sox: SoX v14.0.1" instead.
 
-        my ($vers_output, undef, $success) = qxx(qw(sox -h));
-        return undef unless $success;
-        $vers_output =~ s#[\r\n].*##s;
+        my ($vers_output, $success, $exitstatus) = qxy(qw(sox -h));
+
+        # return undef unless $success;
+        # argh, old soxes have exit status 1 for sox -h (and print to stderr;
+        # rather than stdout like newer ones)
+        use POSIX qw(WIFEXITED);
+        return undef unless WIFEXITED($exitstatus);
 
         if (defined $vers_output) {
+            $vers_output =~ s#[\r\n].*##s;
+
             ($soxver) = $vers_output =~ /(?:Version |v)(\d+\.\d+\.\d+)/
                 or warn "Strange sox -h output (first line): $vers_output\n";
+            return undef unless defined $soxver;
         }
 
         use version;
@@ -206,6 +241,55 @@ C<"-1"/"-2"/"-4"/"-8"> by then.  Note that the old flags were still recognized
 
 1;
 
+# Sample -V3 output from sox:
+
+# 12.17.9:
+#
+#    sox: invalid option -- 3
+# (hehe, but as long as it isn't an error, why not)
+#    sox: Detected file format type: ogg
+#
+#    sox: Input file t/sine.ogg: using sample rate 44100
+#            size shorts, encoding Vorbis, 2 channels
+#    sox: Do not support Vorbis with 16-bit data.  Forcing to Signed.
+#    sox: Writing Wave file: Microsoft PCM format, 2 channels, 44100 samp/sec
+#    sox:         176400 byte/sec, 4 block align, 16 bits/samp
+#    sox: Output file sine.wav: using sample rate 44100
+#            size shorts, encoding signed (2's complement), 2 channels
+#    sox: Output file: comment "Processed by SoX"
+#    
+#    sox: Finished writing Wave file, 1764000 data bytes 441000 samples
+#
+# and 14.0.1:
+#    sox: SoX v14.0.1
+#    
+#    Input File     : 't/sine.ogg'
+#    Sample Size    : 16-bit (2 bytes)
+#    Sample Encoding: Vorbis
+#    Channels       : 2
+#    Sample Rate    : 44100
+#    Duration       : 00:10.00 = 441000 samples = 750 CDDA sectors
+#    Endian Type    : little
+#    Reverse Nibbles: no
+#    Reverse Bits   : no
+#    
+#    sox wav: Do not support Vorbis with 16-bit data.  Forcing to Signed.
+#    
+#    Output File    : 'sine.wav'
+#    Sample Size    : 16-bit (2 bytes)
+#    Sample Encoding: signed (2's complement)
+#    Channels       : 2
+#    Sample Rate    : 44100
+#    Duration       : 00:10.00 = 441000 samples = 750 CDDA sectors
+#    Endian Type    : little
+#    Reverse Nibbles: no
+#    Reverse Bits   : no
+#    Comment        : 'Processed by SoX'
+#    
+#    sox sox: effects chain: input      44100Hz 2 channels 16 bits (multi)
+#    sox sox: effects chain: output     44100Hz 2 channels 16 bits (multi)
+
+
 =head1 SEE ALSO
 
 =over 8
